@@ -1,10 +1,11 @@
+from qtpy.QtCore import Qt
+from qtpy.QtWidgets import QApplication
+
 from superqt import QDoubleSlider
-from superqt.qtcompat.QtCore import Qt
-from superqt.qtcompat.QtWidgets import QApplication
 
 app = QApplication([])
 
-sld = QDoubleSlider(Qt.Horizontal)
+sld = QDoubleSlider(Qt.Orientation.Horizontal)
 sld.setRange(0, 1)
 sld.setValue(0.5)
 sld.show()
